@@ -1,15 +1,22 @@
 package Koha::Contrib::Sudoc::TransferDaemon;
-# ABSTRACT: Daemon de transfert de fichiers
-$Koha::Contrib::Sudoc::TransferDaemon::VERSION = '2.02';
+# ABSTRACT: Service de transfert de fichiers
+$Koha::Contrib::Sudoc::TransferDaemon::VERSION = '2.03';
 use Moose;
 use Modern::Perl;
 use AnyEvent;
 use Mail::Box::Manager;
 use DateTime;
+use Log::Dispatch;
+use Log::Dispatch::Screen;
+use Log::Dispatch::Syslog;
 use Koha::Contrib::Sudoc;
 
 
-has sudoc => ( is => 'rw', isa => 'Sudoc', default => sub { Koha::Contrib::Sudoc->new } );
+has sudoc => (
+    is => 'rw',
+    isa => 'Koha::Contrib::Sudoc',
+    default => sub { Koha::Contrib::Sudoc->new }
+);
 
 has mgr => (
     is => 'rw',
@@ -17,7 +24,14 @@ has mgr => (
     default => sub { Mail::Box::Manager->new },
 );
 
-has verbose => ( is => 'rw', isa => 'Bool', default => 0 );
+has daemon_id => ( is => 'rw', isa => 'Str');
+
+# Le logger
+has log => (
+    is => 'rw',
+    isa => 'Log::Dispatch',
+    default => sub { Log::Dispatch->new() },
+);
 
 
 # Global
@@ -27,7 +41,19 @@ my $daemon_id = 'sudoc-trans';
 sub BUILD {
     my $self = shift;
 
-    say "Starting ABES transfer daemon";
+    # On log à la fois à l'écran et dans syslog
+    $self->log->add( Log::Dispatch::Screen->new(
+        name      => 'screen',
+        min_level => 'notice',
+    ) );
+    $self->log->add( Log::Dispatch::Syslog->new(
+        name      => 'syslog',
+        min_level => 'notice',
+        ident     => $daemon_id . '-' . $self->sudoc->c->{iln}, 
+        binmode   => ':encoding(utf8)',
+    ) );
+
+    $self->log->notice( "Démarrage du service de transfert ABES\n" );
 
     my $timeout = $self->sudoc->c->{trans}->{timeout};
     my $idle = AnyEvent->timer(
@@ -39,34 +65,36 @@ sub BUILD {
 }
 
 
+# Envoi à l'ABES d'un email GTD en réponse à un message 'status 9'. Celui-ci contient le numéro du job
 sub send_gtd {
-    my ($self, $msg_abes) = @_;
+    my ($self, $msg) = @_;
 
-    # Récupération dans le courriel de l'ABES des info dont a besoin
-    # pour construire la réponse
-    my $body = $msg_abes->body;
+    # Récupération dans le courriel de l'ABES des info dont on a besoin pour
+    # construire la réponse
+    my $body = $msg->body;
     my ($jobid) = $body =~ /JobId\s*:\s*(\d*)/;
     my ($iln)   = $body =~ /\/iln(\d*)\//;
 
     # La date
     my $year = DateTime->now->year;
 
-    say "Send GTD: ILN $iln, job $jobid, year $year";
+    $self->log->notice(
+        "Réception message 'status 9'. Envoi GTD: ILN $iln, job $jobid, année $year\n" );
 
-    my $conf = $self->sudoc->c->{trans};
+    my $c = $self->sudoc->c->{trans};
 
     my $head = Mail::Message::Head->new;
-    $head->add( From => $conf->{email}->{koha} );
-    $head->add( To => $conf->{email}->{abes} );
+    $head->add( From => $c->{email}->{koha} );
+    $head->add( To => $c->{email}->{abes} );
     $head->add( Subject => 'GET TITLE DATA' );
 
     $body = Mail::Message::Body::Lines->new(
         data =>
             "GTD_ILN = $iln\n" .
             "GTD_YEAR = $year\n" .
-            "GTD_FILE_TO = " . $conf->{ftp_host} . "\n" .
+            "GTD_FILE_TO = " . $c->{ftp_host} . "\n" .
             "GTD_ORDER = TR$jobid*\n" .
-            "GTD_REMOTE_DIR = spool/$iln/staged\n",
+            "GTD_REMOTE_DIR = staged\n",
     );
 
     my $message = Mail::Message->new(
@@ -77,16 +105,9 @@ sub send_gtd {
 
 
 sub move_to_waiting {
-    my ($self, $msg) = @_;
-
-    my $body = $msg->body;
-    my ($iln) = $body =~ /GTD_ILN\s*=\s*(\d*)/i;
- 
-    say "End file transfer from ABES for ILN $iln";
-
-    my $sudoc = $self->sudoc;
-    $sudoc->iln($iln);
-    $sudoc->spool->staged_to_waiting();
+    my $self = shift;
+    $self->log->notice("Réception message 'status 0'. Fin transfert. Déplacement de 'done' à 'waiting'\n");
+    $self->sudoc->spool->staged_to_waiting();
 }
 
 
@@ -99,9 +120,9 @@ sub transfert_abes {
 
     my $folder = $self->mgr->open( folder => $mbox, access => 'rw' );
     for my $message ($folder->messages) {
-        given ($message->subject()) {
-            when ( /status is 9/ ) { $self->send_gtd( $message ); }
-            when ( /status: 0/ ) { $self->move_to_waiting( $message ); }
+        for ($message->subject()) {
+            if    ( /status is 9/ ) { $self->send_gtd($message);        }
+            elsif ( /status: 0/ )   { $self->move_to_waiting(); }
         }
         $message->delete;
     }
@@ -118,11 +139,11 @@ __END__
 
 =head1 NAME
 
-Koha::Contrib::Sudoc::TransferDaemon - Daemon de transfert de fichiers
+Koha::Contrib::Sudoc::TransferDaemon - Service de transfert de fichiers
 
 =head1 VERSION
 
-version 2.02
+version 2.03
 
 =head1 AUTHOR
 
